package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Apr 9, 2026
License: MIT
Opens a new window with license information.
Imports: 16
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type HookInput struct {
SessionID string `json:"session_id"`
Event string `json:"event"`
ToolName string `json:"tool_name"`
ToolInput json.RawMessage `json:"tool_input"`
Output string `json:"output"`
}
HookInput represents the JSON input from Claude Code hooks.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.